import { PathEvent } from './path-events.ts';
/**
 * Run a stringified function with arguments asynchronously
 * @param {object} args Map of key/value arguments
 * @param {string} fn Function as string
 * @param {boolean} async Run with async (returns a promise)
 * @return {T | Promise<T>} Function return result
 */
export declare function fn<T>(args: object, fn: string, async?: boolean): T;
/**
 * Get profile image from Gravatar
 *
 * @param {string} email Account email address
 * @param {string} def Default image, can be a link or '404', see: https://docs.gravatar.com/general/images/
 * @returns {string} Gravatar URL
 */
export declare function gravatar(email: string, def?: string): string;
/**
 * Escape any regex special characters to avoid misinterpretation during search
 *
 * @param {string} value String which should be escaped
 * @return {string} New escaped sequence
 */
export declare function escapeRegex(value: string): string;
export type Listener = (event: PathEvent, ...args: any[]) => any;
export type Unsubscribe = () => void;
